@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,21 +17,23 @@
 */
 
 #include "filterconverttosieveresultdialog.h"
-#include "PimCommon/SieveSyntaxHighlighter"
-#include "PimCommon/SieveSyntaxHighlighterUtil"
 #include "kpimtextedit/plaintexteditor.h"
 #include "kpimtextedit/plaintexteditorwidget.h"
 #include <PimCommon/PimUtil>
+#include "filterconverttosievepurposemenuwidget.h"
 
 #include <KLocalizedString>
-
-#include <QHBoxLayout>
+#include <KSyntaxHighlighting/Definition>
+#include <KSyntaxHighlighting/SyntaxHighlighter>
+#include <KSyntaxHighlighting/Theme>
 
 #include <KSharedConfig>
+#include <KMessageBox>
 #include <KConfigGroup>
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
+#include <QTemporaryFile>
 
 using namespace MailCommon;
 
@@ -53,13 +56,25 @@ FilterConvertToSieveResultDialog::FilterConvertToSieveResultDialog(QWidget *pare
     mEditor = new KPIMTextEdit::PlainTextEditorWidget;
     mEditor->editor()->setSpellCheckingSupport(false);
     mEditor->setObjectName(QStringLiteral("editor"));
-    PimCommon::SieveSyntaxHighlighter *syntaxHighlighter = new PimCommon::SieveSyntaxHighlighter(mEditor->editor()->document());
-    PimCommon::SieveSyntaxHighlighterUtil sieveHighlighterutil;
-    const QStringList capabilities = sieveHighlighterutil.fullCapabilities();
-    syntaxHighlighter->addCapabilities(capabilities);
+    auto syntaxHighlighter = new KSyntaxHighlighting::SyntaxHighlighter(mEditor->editor()->document());
+    syntaxHighlighter->setDefinition(mSyntaxRepo.definitionForName(QStringLiteral("Sieve")));
+    syntaxHighlighter->setTheme((palette().color(QPalette::Base).lightness() < 128)
+                                ? mSyntaxRepo.defaultTheme(KSyntaxHighlighting::Repository::DarkTheme)
+                                : mSyntaxRepo.defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
     topLayout->addWidget(mEditor);
     topLayout->addWidget(buttonBox);
 
+    FilterconverttosievePurposeMenuWidget *purposeMenu = new FilterconverttosievePurposeMenuWidget(this, this);
+    if (purposeMenu->menu()) {
+        QPushButton *mShareButton = new QPushButton(i18n("Share..."), this);
+        mShareButton->setMenu(purposeMenu->menu());
+        mShareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
+        purposeMenu->setEditorWidget(mEditor->editor());
+        buttonBox->addButton(mShareButton, QDialogButtonBox::ActionRole);
+    } else {
+        delete purposeMenu;
+    }
+
     readConfig();
 }
 
